@@ -2,17 +2,20 @@ SERVICES = [
     "airtable",
     "asana",
     "atlassian",
+    "basecamp",
     "bitbucket",
     "circleci",
     "close",
     "cloudamqp",
     "cloudflare",
+    "clubhouse",
     "codecov",
     "confluence",
     "coveralls",
     "digitalocean",
     "discord",
     "docker",
+    "epicgames",
     "gandi",
     "geckoboard",
     "github",
