@@ -16,16 +16,14 @@ class BaseServiceAPI:
         module_relpath = self.__class__.__module__
         return module_relpath.rsplit(".", 1)[1]
 
-    def __init__(self):
-        self.summary = self.get_summary()
-
     def get_summary(self):
         raise NotImplementedError
 
     def _print_summary(self, verbose=False):
-        click.echo(f"Current {self.name} status: {self.summary.status.name}")
+        summary = self.get_summary()
+        click.echo(f"Current {self.name} status: {summary.status.name}")
 
-        incidents = self.summary.incidents
+        incidents = summary.incidents
         if incidents:
             click.echo("Registered events:")
             for incident in incidents:
@@ -44,6 +42,6 @@ class BaseServiceAPI:
                         else:
                             click.echo(f"    - {component.name}")
 
-        if incidents or not self.summary.status.is_ok:
+        if incidents or not summary.status.is_ok:
             click.echo()
             click.echo(f"More: {self.status_url}")
