@@ -65,7 +65,7 @@ class ServiceAPI(BaseServiceAPI):
             Incident(
                 id=incident["id"],
                 name=incident["title"],
-                status=incident["status_prod"],
+                status=incident["state"],
                 components=[
                     Component(
                         name=component["system"],
@@ -109,4 +109,5 @@ class ServiceAPI(BaseServiceAPI):
             is_ok=worst_status in (STATUS_GREEN, STATUS_BLUE),
         )
 
-        return Summary(status, components, incidents)
+        self.summary = Summary(status, components, incidents)
+        return self.summary
